Flask-Images
============

[![Travis Build Status][travis-badge]][travis]

Flask-Images is a Flask extension that provides dynamic image resizing for your application.

[Read the docs][docs], [try the demo][demo], have fun, and good luck!


[travis-badge]: https://img.shields.io/travis/mikeboers/Flask-Images/develop.svg?logo=travis&label=travis
[travis]: https://travis-ci.org/mikeboers/Flask-Images

[docs]: https://mikeboers.github.io/Flask-Images/
[demo]: https://flask-images.herokuapp.com/
